betty.test_utils.serve module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.serve module

Test utilities for `betty.serve`.

class betty.test_utils.serve.NoOpProjectServer

  Bases: `NoOpServer`, `ProjectServer`

  A project server that does nothing.

class betty.test_utils.serve.NoOpServer

  Bases: `Server`

  A server that does nothing.

  __init__(*_: Any, **__: Any)
  property public_url: str

    The server’s public URL.

  async show() → None

    Show the served site to the user.

  async start() → None

    Start the server.

  async stop() → None

    Stop the server.